@@ -101,8 +101,8 @@ class _ApproxDecisionMaker:
             if self.qFunctions[i].get_coeffs() is None:
                 q_value = 0
             else:
-                q_value = self.qFunctions[i].f(values_of_continuous_features=continuous_feature_values,
-                                               values_of_indicator_features=indicator_feature_values)
+                q_value = self.qFunctions[i].f(x_cont=continuous_feature_values,
+                                               x_bin=indicator_feature_values)
 
             if q_value < minimum:
                 minimum = q_value
@@ -261,7 +261,7 @@ class ApproximatePolicyIteration:
 
             # store iteration, exploration rate, and forgetting factor
             self.itr_i.append(itr)
-            self.itr_forgetting_factor.append(self.learningRule.get_forgetting_factor(itr=itr))
+            self.itr_forgetting_factor.append(self.learningRule.get_learning_rate(itr=itr))
             self.itr_exploration_rate.append(self.appoxDecisionMaker.explorationRule.get_epsilon(itr=itr))
 
             # update the iteration of the approximate decision maker (to calculate exploration rate)
@@ -335,7 +335,7 @@ class ApproximatePolicyIteration:
             self.itr_error.append(self.states[0].costToGo - predicted_cost)
 
         # update q-functions
-        forgetting_factor = self.learningRule.get_forgetting_factor(itr=itr)
+        forgetting_factor = self.learningRule.get_learning_rate(itr=itr)
 
         for s in self.states:
             q_index = index_of_an_action_combo(s.actionCombo)
@@ -390,7 +390,7 @@ class ApproximatePolicyIteration:
         f.tight_layout()
         f.align_ylabels()
 
-        output_figure(plt=plt, filename=filename)
+        output_figure(plt=plt, file_name=filename)
 
     def plot_cost_itr(self, moving_ave_window=None,
                       y_range=None,
@@ -561,7 +561,7 @@ class MultiApproximatePolicyIteration:
         # export iterations
         if folder_to_save_iterations is not None:
             for o in self.optimizers:
-                o.export_results(csv_file=folder_to_save_iterations + '/{}.csv'.format(o.name))
+                o.export_results(csv_filename=folder_to_save_iterations + '/{}.csv'.format(o.name))
 
         # find the best option
         minimum = float('inf')
