@@ -4,7 +4,6 @@ from enum import Enum
 import matplotlib.pyplot as plt
 import numpy as np
 from numpy.polynomial.polynomial import polyfit
-from numpy.random import choice
 from scipy.stats import pearsonr
 
 import deampy.in_out_functions as IO
@@ -53,7 +52,7 @@ class ParameterAnalyzer:
         """
         :param csvfile_param_values: (string) csv file where the parameter values are located
             assumes that the first row of this csv file contains the parameter names and each
-            column contains the parameter values
+            column contains the parameter values.
         :param columns_to_be_deleted: (list of string) list of column names to be deleted from analysis
         """
 
@@ -75,8 +74,8 @@ class ParameterAnalyzer:
             It assumes that
                 1) the first row contains the name of all parameters
                 2) rows contains the weight and the parameter values
-                3) rows are in decreasing order of parameter weights
-        :param n: (int) number of parameter values to resamples
+                3) rows are in decreasing order of parameter weights.
+        :param n: (int) number of parameter values to resamples.
         :param weight_col: (int) index of the columns where the weights of parameter values are located.
         :param csvfile_resampled_params: (string) csvfile where the resampled parameter values will be stored.
             The first row will be the names of parameters.
@@ -256,20 +255,16 @@ class ParameterAnalyzer:
                 # get the current axis
                 ax = axarr[i, j]
 
-                if j == 0:
-                    ax.set_ylabel(info_of_param_info_to_include[i].label)
-                if i == n-1:
-                    ax.set_xlabel(info_of_param_info_to_include[j].label)
-
+                # plot histogram for diagonal elements
                 if i == j:
                     # plot histogram
                     Fig.add_histogram_to_ax(
                         ax=ax,
                         data=info_of_param_info_to_include[i].values,
-                        x_range=info_of_param_info_to_include[i].range
+                        x_range=info_of_param_info_to_include[i].range,
                     )
-                    ax.set_yticklabels([])
-                    ax.set_yticks([])
+                    # ax.set_yticklabels([])
+                    # ax.set_yticks([])
 
                 else:
                     ax.scatter(info_of_param_info_to_include[j].values,
@@ -287,9 +282,14 @@ class ParameterAnalyzer:
                     ax.text(0.95, 0.95, '{0:.2f}'.format(corr), transform=ax.transAxes, fontsize=6,
                             va='top', ha='right')
 
+                if j == 0:
+                    ax.set_ylabel(info_of_param_info_to_include[i].label)
+                if i == n-1:
+                    ax.set_xlabel(info_of_param_info_to_include[j].label)
+
         f.align_ylabels(axarr[:, 0])
         f.tight_layout()
-        output_figure(plt=f, filename=fig_filename, dpi=300)
+        output_figure(plt=f, file_name=fig_filename, dpi=300)
 
     def export_means_and_intervals(self,
                                    poster_file='ParameterEstimates.csv',
